@@ -9,6 +9,9 @@ class HTTPException(Exception):
         if msg:
             self.msg = msg
 
+    def with_traceback(self, tb) -> BaseException:
+        return True
+
     def pack(self):
         return dict(error=self.message, msg=getattr(self, 'msg', '')), self.code
 
